@@ -5,6 +5,7 @@ import yt_playlist_dl
 
 
 def main() -> None:
+    """CLI entry point"""
     parser = argparse.ArgumentParser(
         description='Download youtube playlists'
     )
@@ -16,4 +17,4 @@ def main() -> None:
     )
 
     args = parser.parse_args()
-    yt_playlist_dl.download_videos(args.urls)
+    yt_playlist_dl.download_playlists(args.urls)
